/*
    run-getkey.cpp

    This file is part of QGpgME's test suite.
    Copyright (c) 2018 Intevation GmbH

    QGpgME is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License,
    version 2, as published by the Free Software Foundation.

    QGpgME is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifdef HAVE_CONFIG_H
 #include "config.h"
#endif

#include "context.h"
#include "key.h"

#include <memory>
#include <sstream>
#include <iostream>

int main(int argc, char **argv)
{
    GpgME::initializeLibrary();
    for (int i = 0; i < 100000000; i++)
    {
        auto ctx = std::unique_ptr<GpgME::Context> (GpgME::Context::createForProtocol(GpgME::OpenPGP));
        if (!ctx) {
            std::cerr << "Failed to get Context";
            return -1;
        }
        ctx->setKeyListMode (GpgME::KeyListMode::Local |
                GpgME::KeyListMode::Signatures |
                GpgME::KeyListMode::Validate |
                GpgME::KeyListMode::WithTofu);
        GpgME::Error err;
        const auto key = ctx->key (argv[1], err, false);
        std::stringstream ss;

        ss << "Key " << i << " Err: " << err.asString() << "\n" << key;

        std::cout << ss.str();
    }

    return 0;
}
